@@ -1,5 +1,5 @@
 # Settings to be used when running unit tests
-# python manage.py test --settings=lazysignup.test_settings lazysignup
+# python manage.py test lazysignup
 
 DATABASES = {
     'default': {
@@ -32,5 +32,6 @@ LAZYSIGNUP_USER_AGENT_BLACKLIST = [
 ]
 
 ROOT_URLCONF = 'testproject.urls'
+SECRET_KEY = 'non-empty-key'
 
 LAZYSIGNUP_USER_MODEL = 'lazysignup.CustomUser'
